==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/opsworks/kotlin/inputs/MemcachedLayerLoadBasedAutoScalingUpscalingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opsworks.kotlin.inputs

import com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property alarms
 * @property cpuThreshold
 * @property ignoreMetricsTime
 * @property instanceCount
 * @property loadThreshold
 * @property memoryThreshold
 * @property thresholdsWaitTime
 */
public data class MemcachedLayerLoadBasedAutoScalingUpscalingArgs(
    public val alarms: Output<List<String>>? = null,
    public val cpuThreshold: Output<Double>? = null,
    public val ignoreMetricsTime: Output<Int>? = null,
    public val instanceCount: Output<Int>? = null,
    public val loadThreshold: Output<Double>? = null,
    public val memoryThreshold: Output<Double>? = null,
    public val thresholdsWaitTime: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs> {
    override fun toJava():
        com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs =
        com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs.builder()
            .alarms(alarms?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .cpuThreshold(cpuThreshold?.applyValue({ args0 -> args0 }))
            .ignoreMetricsTime(ignoreMetricsTime?.applyValue({ args0 -> args0 }))
            .instanceCount(instanceCount?.applyValue({ args0 -> args0 }))
            .loadThreshold(loadThreshold?.applyValue({ args0 -> args0 }))
            .memoryThreshold(memoryThreshold?.applyValue({ args0 -> args0 }))
            .thresholdsWaitTime(thresholdsWaitTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MemcachedLayerLoadBasedAutoScalingUpscalingArgs].
 */
@PulumiTagMarker
public class MemcachedLayerLoadBasedAutoScalingUpscalingArgsBuilder internal constructor() {
    private var alarms: Output<List<String>>? = null

    private var cpuThreshold: Output<Double>? = null

    private var ignoreMetricsTime: Output<Int>? = null

    private var instanceCount: Output<Int>? = null

    private var loadThreshold: Output<Double>? = null

    private var memoryThreshold: Output<Double>? = null

    private var thresholdsWaitTime: Output<Int>? = null

    /**
     * @param value
     */
    @JvmName("xgargbeimrtwhqni")
    public suspend fun alarms(`value`: Output<List<String>>) {
        this.alarms = value
    }

    @JvmName("wrnglglvibfojntr")
    public suspend fun alarms(vararg values: Output<String>) {
        this.alarms = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("cphvhftuuovinxyd")
    public suspend fun alarms(values: List<Output<String>>) {
        this.alarms = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("oxueyqhgoaguyvab")
    public suspend fun cpuThreshold(`value`: Output<Double>) {
        this.cpuThreshold = value
    }

    /**
     * @param value
     */
    @JvmName("cnpsvxwiiiohlrtk")
    public suspend fun ignoreMetricsTime(`value`: Output<Int>) {
        this.ignoreMetricsTime = value
    }

    /**
     * @param value
     */
    @JvmName("xojulynabptbgnmh")
    public suspend fun instanceCount(`value`: Output<Int>) {
        this.instanceCount = value
    }

    /**
     * @param value
     */
    @JvmName("ygspxjnfhrvfakdj")
    public suspend fun loadThreshold(`value`: Output<Double>) {
        this.loadThreshold = value
    }

    /**
     * @param value
     */
    @JvmName("dvucqalutjntusiq")
    public suspend fun memoryThreshold(`value`: Output<Double>) {
        this.memoryThreshold = value
    }

    /**
     * @param value
     */
    @JvmName("wlhuejxeoknbdsob")
    public suspend fun thresholdsWaitTime(`value`: Output<Int>) {
        this.thresholdsWaitTime = value
    }

    /**
     * @param value
     */
    @JvmName("aeywnfngdldbxryf")
    public suspend fun alarms(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alarms = mapped
    }

    /**
     * @param values
     */
    @JvmName("asibguhcarhyhviq")
    public suspend fun alarms(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.alarms = mapped
    }

    /**
     * @param value
     */
    @JvmName("wepihkkrxlqvxmxe")
    public suspend fun cpuThreshold(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cpuThreshold = mapped
    }

    /**
     * @param value
     */
    @JvmName("jrupsxokgjwodytr")
    public suspend fun ignoreMetricsTime(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ignoreMetricsTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("fcmmvusingjomdon")
    public suspend fun instanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceCount = mapped
    }

    /**
     * @param value
     */
    @JvmName("qovifpgkpgbpnijc")
    public suspend fun loadThreshold(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadThreshold = mapped
    }

    /**
     * @param value
     */
    @JvmName("myajkttahdegjjag")
    public suspend fun memoryThreshold(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.memoryThreshold = mapped
    }

    /**
     * @param value
     */
    @JvmName("jkguuakrwjvcywng")
    public suspend fun thresholdsWaitTime(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thresholdsWaitTime = mapped
    }

    internal fun build(): MemcachedLayerLoadBasedAutoScalingUpscalingArgs =
        MemcachedLayerLoadBasedAutoScalingUpscalingArgs(
            alarms = alarms,
            cpuThreshold = cpuThreshold,
            ignoreMetricsTime = ignoreMetricsTime,
            instanceCount = instanceCount,
            loadThreshold = loadThreshold,
            memoryThreshold = memoryThreshold,
            thresholdsWaitTime = thresholdsWaitTime,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/opsworks/kotlin/inputs/MemcachedLayerLoadBasedAutoScalingUpscalingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opsworks.kotlin.inputs

import com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property alarms
 * @property cpuThreshold
 * @property ignoreMetricsTime
 * @property instanceCount
 * @property loadThreshold
 * @property memoryThreshold
 * @property thresholdsWaitTime
 */
public data class MemcachedLayerLoadBasedAutoScalingUpscalingArgs(
    public val alarms: Output<List<String>>? = null,
    public val cpuThreshold: Output<Double>? = null,
    public val ignoreMetricsTime: Output<Int>? = null,
    public val instanceCount: Output<Int>? = null,
    public val loadThreshold: Output<Double>? = null,
    public val memoryThreshold: Output<Double>? = null,
    public val thresholdsWaitTime: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs> {
    override fun toJava(): com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs =
        com.pulumi.aws.opsworks.inputs.MemcachedLayerLoadBasedAutoScalingUpscalingArgs.builder()
            .alarms(alarms?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .cpuThreshold(cpuThreshold?.applyValue({ args0 -> args0 }))
            .ignoreMetricsTime(ignoreMetricsTime?.applyValue({ args0 -> args0 }))
            .instanceCount(instanceCount?.applyValue({ args0 -> args0 }))
            .loadThreshold(loadThreshold?.applyValue({ args0 -> args0 }))
            .memoryThreshold(memoryThreshold?.applyValue({ args0 -> args0 }))
            .thresholdsWaitTime(thresholdsWaitTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MemcachedLayerLoadBasedAutoScalingUpscalingArgs].
 */
@PulumiTagMarker
public class MemcachedLayerLoadBasedAutoScalingUpscalingArgsBuilder internal constructor() {
    private var alarms: Output<List<String>>? = null

    private var cpuThreshold: Output<Double>? = null

    private var ignoreMetricsTime: Output<Int>? = null

    private var instanceCount: Output<Int>? = null

    private var loadThreshold: Output<Double>? = null

    private var memoryThreshold: Output<Double>? = null

    private var thresholdsWaitTime: Output<Int>? = null

    /**
     * @param value
     */
    @JvmName("dwgcvsjxyluccfgj")
    public suspend fun alarms(`value`: Output<List<String>>) {
        this.alarms = value
    }

    @JvmName("vbarynyudojiddyb")
    public suspend fun alarms(vararg values: Output<String>) {
        this.alarms = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mprogltsststnbew")
    public suspend fun alarms(values: List<Output<String>>) {
        this.alarms = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("mrmmlfdregroakmy")
    public suspend fun cpuThreshold(`value`: Output<Double>) {
        this.cpuThreshold = value
    }

    /**
     * @param value
     */
    @JvmName("mjvxrtakovjgrces")
    public suspend fun ignoreMetricsTime(`value`: Output<Int>) {
        this.ignoreMetricsTime = value
    }

    /**
     * @param value
     */
    @JvmName("mxhcnleopvpsjobd")
    public suspend fun instanceCount(`value`: Output<Int>) {
        this.instanceCount = value
    }

    /**
     * @param value
     */
    @JvmName("tbmyqkjmbnsnwkhh")
    public suspend fun loadThreshold(`value`: Output<Double>) {
        this.loadThreshold = value
    }

    /**
     * @param value
     */
    @JvmName("vpoytcaeihiegukc")
    public suspend fun memoryThreshold(`value`: Output<Double>) {
        this.memoryThreshold = value
    }

    /**
     * @param value
     */
    @JvmName("ijfkbltoterlfkkk")
    public suspend fun thresholdsWaitTime(`value`: Output<Int>) {
        this.thresholdsWaitTime = value
    }

    /**
     * @param value
     */
    @JvmName("pixxvesdtihpfpns")
    public suspend fun alarms(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alarms = mapped
    }

    /**
     * @param values
     */
    @JvmName("rpbgnuwcewenofvh")
    public suspend fun alarms(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.alarms = mapped
    }

    /**
     * @param value
     */
    @JvmName("tbrsxbhnunogaidh")
    public suspend fun cpuThreshold(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cpuThreshold = mapped
    }

    /**
     * @param value
     */
    @JvmName("bhlurapxiovmrwyi")
    public suspend fun ignoreMetricsTime(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ignoreMetricsTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("npfjcjerooknxuol")
    public suspend fun instanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceCount = mapped
    }

    /**
     * @param value
     */
    @JvmName("ojsdgsdntcpulhlc")
    public suspend fun loadThreshold(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadThreshold = mapped
    }

    /**
     * @param value
     */
    @JvmName("kwjorhbaxpqfiqan")
    public suspend fun memoryThreshold(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.memoryThreshold = mapped
    }

    /**
     * @param value
     */
    @JvmName("rpuxpcxihifaukfy")
    public suspend fun thresholdsWaitTime(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thresholdsWaitTime = mapped
    }

    internal fun build(): MemcachedLayerLoadBasedAutoScalingUpscalingArgs =
        MemcachedLayerLoadBasedAutoScalingUpscalingArgs(
            alarms = alarms,
            cpuThreshold = cpuThreshold,
            ignoreMetricsTime = ignoreMetricsTime,
            instanceCount = instanceCount,
            loadThreshold = loadThreshold,
            memoryThreshold = memoryThreshold,
            thresholdsWaitTime = thresholdsWaitTime,
        )
}
